Re-exports
pub use api::ApiHealth;pub use api::AttemptResumeEndResponse;pub use api::AttemptResumeRequest;pub use api::AttemptResumeStartResponse;pub use api::AttentionRequest;pub use api::BotSummary;pub use api::CreateSessionRequest;pub use api::DaemonOverview;pub use api::DaemonRuntimeState;pub use api::FinalOutputRequest;pub use api::MentionTarget;pub use api::RestartSessionRequest;pub use api::ResumeSessionRequest;pub use api::SessionGroup;pub use api::SessionInputRequest;pub use api::SessionLocateInfo;pub use api::SessionSummary;pub use api::TerminalInfo;pub use ask::AskOption;pub use ask::AskQuestion;pub use ask::AskRequest;pub use ask::AskResult;pub use ask::legacy_selected;pub use config::BotConfig;pub use config::Config;pub use config::DaemonConfig;pub use config::LarkConfig;pub use config::MessageQuotaConfig;pub use config::OncallChatBinding;pub use config::QuotaEntry;pub use config::ScreenAnalyzerConfig;pub use config::WebConfig;pub use ipc::CliUsageLimitKind;pub use ipc::CliUsageLimitState;pub use ipc::DaemonToWorker;pub use ipc::DisplayMode;pub use ipc::FinalOutputKind;pub use ipc::InitConfig;pub use ipc::ScreenStatus;pub use ipc::TermActionKey;pub use ipc::TranscriptChoice;pub use ipc::TuiPromptOption;pub use ipc::WorkerToDaemon;pub use paths::BeamPaths;pub use permissions::TalkEvaluation;pub use permissions::TalkReason;pub use permissions::can_operate;pub use permissions::evaluate_talk;pub use permissions::get_owner_open_id;pub use permissions::grant_restricted;pub use permissions::is_owner;pub use schedule_parser::ParsedNaturalSchedule;pub use schedule_parser::parse_natural_schedule;pub use schedule_parser::parse_schedule;pub use schedule_store::CreateTaskInput;pub use schedule_store::ParsedSchedule;pub use schedule_store::ParsedScheduleKind;pub use schedule_store::ScheduleChatType;pub use schedule_store::ScheduleDeliver;pub use schedule_store::ScheduleRepeat;pub use schedule_store::ScheduleStoreError;pub use schedule_store::ScheduleTaskUpdate;pub use schedule_store::ScheduledTask;pub use schedule_store::append_output_log;pub use schedule_store::create_task;pub use schedule_store::get_task;pub use schedule_store::list_tasks;pub use schedule_store::mark_run;pub use schedule_store::remove_task;pub use schedule_store::update_task;pub use session::AdoptedFrom;pub use session::AgentAttention;pub use session::ChatMode;pub use session::PendingResponseCardState;pub use session::Session;pub use session::SessionScope;pub use session::SessionStatus;pub use workflow::EventDraft;pub use workflow::EventLog;pub use workflow::WorkflowActor;pub use workflow::WorkflowEventEnvelope;pub use workflow_actions::CompleteActivityCancelInput;pub use workflow_actions::CompleteNodeCancelInput;pub use workflow_actions::CompleteRunCancelInput;pub use workflow_actions::CreateWaitInput;pub use workflow_actions::DeliverCancelInput;pub use workflow_actions::ExpireWaitInput;pub use workflow_actions::RequestCancelInput;pub use workflow_actions::ResolveWaitInput;pub use workflow_actions::WaitKind;pub use workflow_actions::WaitOnTimeout;pub use workflow_actions::WaitResolution;pub use workflow_actions::complete_activity_cancel;pub use workflow_actions::complete_node_cancel;pub use workflow_actions::complete_run_cancel;pub use workflow_actions::create_wait;pub use workflow_actions::deliver_cancel;pub use workflow_actions::expire_wait;pub use workflow_actions::request_cancel;pub use workflow_actions::resolve_wait;pub use workflow_binding::BindingContext;pub use workflow_binding::BindingError;pub use workflow_binding::LoopContext;pub use workflow_binding::resolve_bindings;pub use workflow_binding::resolve_bound_string;pub use workflow_cold_scan::ColdScanStats;pub use workflow_cold_scan::ColdWorkflowRun;pub use workflow_cold_scan::scan_cold_workflow_runs;pub use workflow_definition::DecisionNode;pub use workflow_definition::HostExecutorNode;pub use workflow_definition::HumanGate;pub use workflow_definition::LoopNode;pub use workflow_definition::LoopOutputProjection;pub use workflow_definition::LoopTerminate;pub use workflow_definition::ParamDef;pub use workflow_definition::RetryPolicy;pub use workflow_definition::SubagentNode;pub use workflow_definition::WorkflowDefaults;pub use workflow_definition::WorkflowDefinition;pub use workflow_definition::WorkflowNode;pub use workflow_definition::parse_workflow_definition;pub use workflow_orchestrator::OrchestratorAction;pub use workflow_orchestrator::decide_next_actions;pub use workflow_orchestrator::topological_order;pub use workflow_output::WORKFLOW_OUTPUT_BEGIN;pub use workflow_output::WORKFLOW_OUTPUT_END;pub use workflow_output::parse_workflow_output;pub use workflow_output::with_workflow_output_protocol;pub use workflow_projection::EventWindow;pub use workflow_projection::EventWindowOpts;pub use workflow_projection::event_seq_from_id;pub use workflow_projection::infer_run_status;pub use workflow_projection::read_event_window;pub use workflow_projection::read_run_events_pure;pub use workflow_resume::PriorReconcileRecoveryOutcome;pub use workflow_resume::ScheduleResumeOutcome;pub use workflow_resume::ScheduleResumeResult;pub use workflow_resume::recover_prior_reconcile_result;pub use workflow_resume::resume_schedule_dangling_effects;pub use workflow_run::BootstrapWorkflowRunInput;pub use workflow_run::RunChatBinding;pub use workflow_run::WorkflowOutputRef;pub use workflow_run::WorkflowRunBootstrap;pub use workflow_run::bootstrap_workflow_run;pub use workflow_run::mint_workflow_run_id;pub use workflow_run::normalize_workflow_params;pub use workflow_runtime::HostExecutorPrepareResult;pub use workflow_runtime::RecoveryResult;pub use workflow_runtime::RunLoopResult;pub use workflow_runtime::RunLoopStopReason;pub use workflow_runtime::RunTickResult;pub use workflow_runtime::WorkflowDispatchOutcome;pub use workflow_runtime::WorkflowDispatchRun;pub use workflow_runtime::WorkflowDispatchSession;pub use workflow_runtime::WorkflowExecutionHooks;pub use workflow_runtime::WorkflowRuntimeContext;pub use workflow_runtime::complete_node_failed;pub use workflow_runtime::complete_node_succeeded;pub use workflow_runtime::complete_run_failed;pub use workflow_runtime::complete_run_succeeded;pub use workflow_runtime::derive_workflow_idempotency_key;pub use workflow_runtime::dispatch_gate;pub use workflow_runtime::dispatch_work;pub use workflow_runtime::finish_loop;pub use workflow_runtime::finish_loop_iteration;pub use workflow_runtime::get_host_executor_provider_meta;pub use workflow_runtime::run_loop;pub use workflow_runtime::run_tick;pub use workflow_runtime::start_loop;pub use workflow_runtime::start_loop_iteration;pub use workflow_sidecar::load_effect_input_sidecar;pub use workflow_sidecar::write_effect_input_sidecar;pub use workflow_snapshot::ActivityState;pub use workflow_snapshot::ActivityStatus;pub use workflow_snapshot::AttemptIODTO;pub use workflow_snapshot::AttemptState;pub use workflow_snapshot::AttemptTerminalDTO;pub use workflow_snapshot::BlobPreviewDTO;pub use workflow_snapshot::BotSnapshot;pub use workflow_snapshot::CancelIntent;pub use workflow_snapshot::DanglingSnapshot;pub use workflow_snapshot::EffectAttemptedState;pub use workflow_snapshot::LoopIterationState;pub use workflow_snapshot::LoopIterationStatus;pub use workflow_snapshot::LoopSnapshotDTO;pub use workflow_snapshot::LoopState;pub use workflow_snapshot::LoopStatus;pub use workflow_snapshot::NodeState;pub use workflow_snapshot::NodeStatus;pub use workflow_snapshot::ReconcileResultState;pub use workflow_snapshot::RunSnapshotDTO;pub use workflow_snapshot::RunState;pub use workflow_snapshot::RunStatus;pub use workflow_snapshot::WaitResolutionState;pub use workflow_snapshot::WaitState;pub use workflow_snapshot::read_run_snapshot;
Modules
- api
- ask
- config
- i18n
- ipc
- paths
- permissions
- persist
- Common persistence helpers: atomic JSON file writes with tmp + rename. Sensitive files can opt-in to 0600 permissions on Unix.
- schedule_
parser - schedule_
store - session
- workflow
- workflow_
actions - workflow_
binding - workflow_
cold_ scan - workflow_
definition - workflow_
orchestrator - workflow_
output - workflow_
projection - workflow_
resume - workflow_
run - workflow_
runtime - workflow_
sidecar - workflow_
snapshot
Constants
- DEFAULT_
TERMINAL_ COLS - Default terminal columns used by beam when creating zellij sessions and for reset-to-default resize operations (reference: botmux 160×50).
- DEFAULT_
TERMINAL_ ROWS - Default terminal rows used by beam when creating zellij sessions and for reset-to-default resize operations.