pub fn custom_trigger_rest<'a>(text: &'a str, trigger: &str) -> Option<&'a str>
Text that follows the trigger keyword, with leading separators removed. Returns None when the message is exactly the keyword.
None